@@ -1,6 +1,6 @@
 ;;; ebib-notes.el --- Part of Ebib, a BibTeX database manager  -*- lexical-binding: t -*-
 
-;; Copyright (c) 2003-2016 Joost Kremers
+;; Copyright (c) 2003-2018 Joost Kremers
 ;; All rights reserved.
 
 ;; Author: Joost Kremers <joostkremers@fastmail.fm>
@@ -80,9 +80,9 @@ option is only used for multiple notes files, i.e., when
 
 (defcustom ebib-notes-name-transform-function nil
   "Function for transforming keys into notes file names.
-This only takes effect files when multiple notes files are used.
-If this is nil, the function `ebib-name-transform-function' is
-used instead."
+This only takes effect when multiple notes files are used.  If
+this is nil, the function `ebib-name-transform-function' is used
+instead."
   :group 'ebib-notes
   :type '(choice (const :tag "Use `ebib-name-transform-function'" nil)
                  (function :tag "Apply function")))
@@ -170,7 +170,7 @@ string where point should be located."
             (ebib--notes-locate-note key)))
     (file-readable-p (ebib--create-notes-file-name key))))
 
-;;; one file per note
+;;; One file per note.
 
 (defun ebib--create-notes-file-name (key)
   "Create a notes filename for KEY.
@@ -198,7 +198,7 @@ name is fully qualified by prepending the directory in
           (insert (car note))
           (forward-char (cdr note))))))
 
-;;; common notes file
+;;; Common notes file.
 
 (defun ebib--notes-buffer ()
   "Return the buffer containing the notes file.
