@@ -1,6 +1,6 @@
 ;;; ebib-utils.el --- Part of Ebib, a BibTeX database manager  -*- lexical-binding: t -*-
 
-;; Copyright (c) 2003-2016 Joost Kremers
+;; Copyright (c) 2003-2018 Joost Kremers
 ;; All rights reserved.
 
 ;; Author: Joost Kremers <joostkremers@fastmail.fm>
@@ -50,14 +50,14 @@
 (make-obsolete-variable 'ebib-standard-file-field 'ebib-file-field "24.4")
 (make-obsolete-variable 'ebib-standard-doi-field 'ebib-doi-field "24.4")
 
-;; Make sure we can call bibtex-generate-autokey
+;; Make sure we can call bibtex-generate-autokey.
 (declare-function bibtex-generate-autokey "bibtex" nil)
 
 ;;;;;;;;;;;;;;;;;;;;;;
 ;; global variables ;;
 ;;;;;;;;;;;;;;;;;;;;;;
 
-;; user customisation
+;; User customisation.
 
 (defgroup ebib nil "Ebib: a BibTeX database manager" :group 'tex)
 
@@ -148,7 +148,7 @@ or through the menu."
 
 (defcustom ebib-layout 'full
   "Ebib window layout.
-This option defines how Ebib displays the buffers its uses.  By
+This option defines how Ebib displays the buffers it uses.  By
 default, Ebib takes over the entire frame and creates two windows
 to display the index and the entry buffer.  Alternatively, Ebib
 can use just the right part of the frame (the width can be
@@ -408,21 +408,21 @@ This option is described in the manual/info file in the section
 
 ;; Entry type and field aliases defined by Biblatex.
 (defconst ebib--field-aliases '(("location" . "address")
-                                ("annotation" . "annote")
-                                ("eprinttype" . "archiveprefix")
-                                ("journaltitle" . "journal")
-                                ("sortkey" . "key")
-                                ("file" . "pdf")
-                                ("eprintclass" . "primaryclass")
-                                ("institution" . "school"))
+                            ("annotation" . "annote")
+                            ("eprinttype" . "archiveprefix")
+                            ("journaltitle" . "journal")
+                            ("sortkey" . "key")
+                            ("file" . "pdf")
+                            ("eprintclass" . "primaryclass")
+                            ("institution" . "school"))
   "List of field aliases for Biblatex.")
 
 (defconst ebib--type-aliases '(("Conference" . "InProceedings")
-                               ("Electronic" . "Online")
-                               ("MastersThesis" . "Thesis")
-                               ("PhDThesis" . "Thesis")
-                               ("TechReport" . "Report")
-                               ("WWW" . "Online"))
+                           ("Electronic" . "Online")
+                           ("MastersThesis" . "Thesis")
+                           ("PhDThesis" . "Thesis")
+                           ("TechReport" . "Report")
+                           ("WWW" . "Online"))
   "List of entry type aliases for Biblatex.")
 
 (defcustom ebib-bibtex-dialect 'BibTeX
@@ -436,97 +436,97 @@ assumed to use this dialect.  Possible values are those listed in
                            bibtex-dialect-list)))
 
 (defcustom ebib-biblatex-inheritances '(("all"
-                                         "all"
-                                         (("ids" . none)
-                                          ("crossref" . none)
-                                          ("xref" . none)
-                                          ("entryset" . none)
-                                          ("entrysubtype" . none)
-                                          ("execute" . none)
-                                          ("label" . none)
-                                          ("options" . none)
-                                          ("presort" . none)
-                                          ("related" . none)
-                                          ("relatedoptions" . none)
-                                          ("relatedstring" . none)
-                                          ("relatedtype" . none)
-                                          ("shorthand" . none)
-                                          ("shorthandintro" . none)
-                                          ("sortkey" . none)))
+                                     "all"
+                                     (("ids" . none)
+                                      ("crossref" . none)
+                                      ("xref" . none)
+                                      ("entryset" . none)
+                                      ("entrysubtype" . none)
+                                      ("execute" . none)
+                                      ("label" . none)
+                                      ("options" . none)
+                                      ("presort" . none)
+                                      ("related" . none)
+                                      ("relatedoptions" . none)
+                                      ("relatedstring" . none)
+                                      ("relatedtype" . none)
+                                      ("shorthand" . none)
+                                      ("shorthandintro" . none)
+                                      ("sortkey" . none)))
 
-                                        ("mvbook, book"
-                                         "inbook, bookinbook, suppbook"
-                                         (("author" . "author")
-                                          ("author" . "bookauthor")))
+                                    ("mvbook, book"
+                                     "inbook, bookinbook, suppbook"
+                                     (("author" . "author")
+                                      ("author" . "bookauthor")))
 
-                                        ("mvbook"
-                                         "book, inbook, bookinbook, suppbook"
-                                         (("title" . "maintitle")
-                                          ("subtitle" . "mainsubtitle")
-                                          ("titleaddon" . "maintitleaddon")
-                                          ("shorttitle" . none)
-                                          ("sorttitle" . none)
-                                          ("indextitle" . none)
-                                          ("indexsorttitle" . none)))
+                                    ("mvbook"
+                                     "book, inbook, bookinbook, suppbook"
+                                     (("title" . "maintitle")
+                                      ("subtitle" . "mainsubtitle")
+                                      ("titleaddon" . "maintitleaddon")
+                                      ("shorttitle" . none)
+                                      ("sorttitle" . none)
+                                      ("indextitle" . none)
+                                      ("indexsorttitle" . none)))
 
-                                        ("mvcollection, mvreference"
-                                         "collection, reference, incollection, inreference, suppcollection"
-                                         (("title" . "maintitle")
-                                          ("subtitle" . "mainsubtitle")
-                                          ("titleaddon" . "maintitleaddon")
-                                          ("shorttitle" . none)
-                                          ("sorttitle" . none)
-                                          ("indextitle" . none)
-                                          ("indexsorttitle" . none)))
+                                    ("mvcollection, mvreference"
+                                     "collection, reference, incollection, inreference, suppcollection"
+                                     (("title" . "maintitle")
+                                      ("subtitle" . "mainsubtitle")
+                                      ("titleaddon" . "maintitleaddon")
+                                      ("shorttitle" . none)
+                                      ("sorttitle" . none)
+                                      ("indextitle" . none)
+                                      ("indexsorttitle" . none)))
 
-                                        ("mvproceedings"
-                                         "proceedings, inproceedings"
-                                         (("title" . "maintitle")
-                                          ("subtitle" . "mainsubtitle")
-                                          ("titleaddon" . "maintitleaddon")
-                                          ("shorttitle" . none)
-                                          ("sorttitle" . none)
-                                          ("indextitle" . none)
-                                          ("indexsorttitle" . none)))
+                                    ("mvproceedings"
+                                     "proceedings, inproceedings"
+                                     (("title" . "maintitle")
+                                      ("subtitle" . "mainsubtitle")
+                                      ("titleaddon" . "maintitleaddon")
+                                      ("shorttitle" . none)
+                                      ("sorttitle" . none)
+                                      ("indextitle" . none)
+                                      ("indexsorttitle" . none)))
 
-                                        ("book"
-                                         "inbook, bookinbook, suppbook"
-                                         (("title" . "booktitle")
-                                          ("subtitle" . "booksubtitle")
-                                          ("titleaddon" . "booktitleaddon")
-                                          ("shorttitle" . none)
-                                          ("sorttitle" . none)
-                                          ("indextitle" . none)
-                                          ("indexsorttitle" . none)))
+                                    ("book"
+                                     "inbook, bookinbook, suppbook"
+                                     (("title" . "booktitle")
+                                      ("subtitle" . "booksubtitle")
+                                      ("titleaddon" . "booktitleaddon")
+                                      ("shorttitle" . none)
+                                      ("sorttitle" . none)
+                                      ("indextitle" . none)
+                                      ("indexsorttitle" . none)))
 
-                                        ("collection, reference"
-                                         "incollection, inreference, suppcollection"
-                                         (("title" . "booktitle")
-                                          ("subtitle" . "booksubtitle")
-                                          ("titleaddon" . "booktitleaddon")
-                                          ("shorttitle" . none)
-                                          ("sorttitle" . none)
-                                          ("indextitle" . none)
-                                          ("indexsorttitle" . none)))
+                                    ("collection, reference"
+                                     "incollection, inreference, suppcollection"
+                                     (("title" . "booktitle")
+                                      ("subtitle" . "booksubtitle")
+                                      ("titleaddon" . "booktitleaddon")
+                                      ("shorttitle" . none)
+                                      ("sorttitle" . none)
+                                      ("indextitle" . none)
+                                      ("indexsorttitle" . none)))
 
-                                        ("proceedings"
-                                         "inproceedings"
-                                         (("title" . "booktitle")
-                                          ("subtitle" . "booksubtitle")
-                                          ("titleaddon" . "booktitleaddon")
-                                          ("shorttitle" . none)
-                                          ("sorttitle" . none)
-                                          ("indextitle" . none)
-                                          ("indexsorttitle" . none)))
+                                    ("proceedings"
+                                     "inproceedings"
+                                     (("title" . "booktitle")
+                                      ("subtitle" . "booksubtitle")
+                                      ("titleaddon" . "booktitleaddon")
+                                      ("shorttitle" . none)
+                                      ("sorttitle" . none)
+                                      ("indextitle" . none)
+                                      ("indexsorttitle" . none)))
 
-                                        ("periodical"
-                                         "article, suppperiodical"
-                                         (("title" . "journaltitle")
-                                          ("subtitle" . "journalsubtitle")
-                                          ("shorttitle" . none)
-                                          ("sorttitle" . none)
-                                          ("indextitle" . none)
-                                          ("indexsorttitle" . none))))
+                                    ("periodical"
+                                     "article, suppperiodical"
+                                     (("title" . "journaltitle")
+                                      ("subtitle" . "journalsubtitle")
+                                      ("shorttitle" . none)
+                                      ("sorttitle" . none)
+                                      ("indextitle" . none)
+                                      ("indexsorttitle" . none))))
   "Inheritance scheme for cross-referencing.
 This option defines inheritances for BibLaTeX.  Inheritances are
 specified for pairs of source and target entry type, where the
@@ -821,14 +821,14 @@ Currently, the following problems are marked:
 * Keywords that have not been saved."
   :group 'ebib-faces)
 
-;; generic for all databases
+;; Generic for all databases.
 
-;; constants and variables that are set only once
+;; Constants and variables that are set only once.
 (defvar ebib--initialized nil "T if Ebib has been initialized.")
 
 (defvar ebib--buffer-alist nil "Alist of Ebib buffers.")
 
-;; general bookkeeping
+;; General bookkeeping.
 (defvar ebib--field-history nil "Minibuffer field name history.")
 (defvar ebib--filters-history nil "Minibuffer history for filters.")
 (defvar ebib--citation-history nil "Minibuffer history for citation commands.")
@@ -848,27 +848,27 @@ Currently, the following problems are marked:
 (defvar-local ebib--local-bibtex-filenames nil "A list of a buffer's .bib file(s)")
 (put 'ebib--local-bibtex-filenames 'safe-local-variable (lambda (v) (null (--remove (stringp it) v))))
 
-;; The databases
+;; The databases.
 
-;; the master list and the current database
+;; The master list and the current database.
 (defvar ebib--databases nil "List of structs containing the databases.")
 (defvar ebib--cur-db nil "The database that is currently active.")
 
-;; bookkeeping required when editing field values or @STRING definitions
+;; Bookkeeping required when editing field values or @STRING definitions.
 
 (defvar ebib--hide-hidden-fields t "If set to T, hidden fields are not shown.")
 
-;; the prefix key and the multiline key are stored in a variable so that the
+;; The prefix key and the multiline key are stored in a variable so that the
 ;; user can customise them.
 (defvar ebib--prefix-key ?\;)
 (defvar ebib--multiline-key ?\|)
 
-;; this is an AucTeX variable, but we want to check its value, so let's
+;; This is an AUCTeX variable, but we want to check its value, so let's
 ;; keep the compiler from complaining.
 (eval-when-compile
   (defvar TeX-master))
 
-;; General functions
+;; General functions.
 
 (defun ebib--buffer (buffer)
   "Return the buffer object referred to by BUFFER.
@@ -1013,17 +1013,16 @@ function adds a newline to the message being logged."
 
 (defun ebib--read-file-to-list (filename)
   "Return the contents of FILENAME as a list of lines."
-  (if (and filename                               ; protect against 'filename' being 'nil'
+  (if (and filename                               ; Protect against `filename' being nil.
            (file-readable-p filename))
       (with-temp-buffer
         (insert-file-contents filename)
-        (split-string (buffer-string) "\n" t))))    ; 't' is omit nulls, blank lines in this case
+        (split-string (buffer-string) "\n" 'omit-nulls))))    ; Nulls are empty lines in this case.
 
-;; we sometimes need to walk through lists.  these functions yield the
-;; element directly preceding or following ELEM in LIST. in order to work
-;; properly, ELEM must be unique in LIST, obviously. if ELEM is the
-;; first/last element of LIST, or if it is not contained in LIST at all,
-;; the result is nil.
+;; We sometimes need to walk through lists.  These functions yield the element
+;; directly preceding or following ELEM in LIST.  In order to work properly,
+;; ELEM must be unique in LIST, obviously.  If ELEM is the first/last element of
+;; LIST, or if it is not contained in LIST at all, the result is nil.
 (defun ebib--next-elem (elem list)
   "Return the element following ELEM in LIST.
 If ELEM is the last element, return nil."
@@ -1104,7 +1103,7 @@ the function `ebib--create-file-name-from-key' for details."
         (setq n 1))
        ((null n)
         (setq n (string-to-number (read-string (format "Select file [1-%d]: " (length file-list)))))))
-      (unless (<= 1 n (length file-list))  ; unless n is within range
+      (unless (<= 1 n (length file-list))  ; Unless n is within range.
         (error "[Ebib] No such file (%d)" n))
       (nth (1- n) file-list))))
 
@@ -1128,12 +1127,12 @@ error."
   (cond
    ((= (length urls) 1)
     (setq n 1))
-   ((null n) ; the user didn't provide a numeric prefix argument
+   ((null n) ; The user didn't provide a numeric prefix argument.
     (setq n (string-to-number (read-string (format "Select URL to open [1-%d]: " (length urls)))))))
-  (unless (<= 1 n (length urls))  ; unless n is within range
+  (unless (<= 1 n (length urls))  ; Unless n is within range.
     (error "[Ebib] No such URL (%d)" n))
   (let ((url (nth (1- n) urls)))
-    (if (string-match "\\\\url{\\(.*?\\)}" url) ; see if the url is contained in \url{...}
+    (if (string-match "\\\\url{\\(.*?\\)}" url) ; See if the url is contained in \url{...}.
         (setq url (match-string 1 url)))
     url))
 
@@ -1292,9 +1291,9 @@ VARS is a list as returned by `ebib--local-vars-to-list'.  VARS is
 not modified, instead the new list is returned."
   (--remove (string= (car it) "bibtex-dialect") vars))
 
-;; The numeric prefix argument is 1 if the user gave no prefix argument at
-;; all. The raw prefix argument is not always a number. So we need to do
-;; our own conversion.
+;; The numeric prefix argument is 1 if the user gave no prefix argument at all.
+;; The raw prefix argument is not always a number.  So we need to do our own
+;; conversion.
 (defun ebib--prefix (num)
   "Return NUM if it is a number, otherwise return nil.
 This can be used to check if the user provided a numeric prefix
